@@ -2,7 +2,7 @@
 #' @examples
 #' rpl(5, 2, 3, 4)
 #' @export
-rpn = function(n, lambda, mu= 0, sigma = 1){
+rpn = function(n, lambda = 1, mu= 0, sigma = 1){
   n = runif(n)
   x = qpn(n, lambda, mu, sigma)
   return(x)
